@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-__version__ = "0.4.4 auto-update tlgbotfwk library"
+__version__ = "0.4.16 auto-update tlgbotfwk library"
 
 import asyncio
 from functools import wraps
@@ -16,7 +16,7 @@ import dotenv
 import yaml
 from telegram import Update
 from telegram.constants import ChatAction
-from telegram.ext import Application, CommandHandler as TelegramCommandHandler, ContextTypes, PicklePersistence, CallbackContext, filters
+from telegram.ext import Application, CommandHandler as TelegramCommandHandler, ContextTypes, PicklePersistence, CallbackContext, filters, JobQueue
 from telegram.constants import ParseMode
 
 from .handlers import CommandHandler
@@ -39,6 +39,14 @@ def get_config_path(config_filename: str = "config.yml") -> Path:
 
 class TelegramBotFramework:
     
+    async def send_status_message(self, context: CallbackContext) -> None:
+        if self.status_message_enabled:
+            for chat_id in self.admin_users:
+                try:
+                    await context.bot.send_message(chat_id=chat_id, text="The bot is still active.")
+                except Exception as e:
+                    self.logger.error(f"Failed to send status message to admin {chat_id}: {e}")    
+      
     def with_typing_action(handler):
         @wraps(handler)
         async def wrapper(self, update: Update, context: CallbackContext, *args, **kwargs):
@@ -148,6 +156,9 @@ class TelegramBotFramework:
         self._load_config()
         self._setup_logging()
         self._register_default_commands()
+        
+        # Initialize the status message flag
+        self.status_message_enabled = True
 
     def _load_config(self) -> None:
         if not self.config_path.exists():
@@ -423,7 +434,25 @@ class TelegramBotFramework:
         except Exception as e:
             self.logger.error(f"Error updating tlgbotfwk library: {e}")
             await update.message.reply_text("An error occurred while updating the tlgbotfwk library.")
+   
+    @with_typing_action
+    @with_log_admin
+    @with_register_user
+    async def toggle_status_message(self, update: Update, context: CallbackContext) -> None:
+        """Toggle the status message on or off to indicate whether the bot is active.
 
+        Args:
+            update (Update): _description_
+            context (CallbackContext): _description_
+        """
+        user_id = update.effective_user.id
+        if user_id in self.admin_users:
+            self.status_message_enabled = not self.status_message_enabled
+            status = "enabled" if self.status_message_enabled else "disabled"
+            await update.message.reply_text(f"Status message has been {status}.")
+        else:
+            await update.message.reply_text("You are not authorized to use this command.")
+            
     async def post_init(self, app: Application) -> None:
         try:
             self.logger.info("Bot post-initialization complete!")
@@ -501,9 +530,18 @@ class TelegramBotFramework:
         for handler in external_handlers:
             app.add_handler(TelegramCommandHandler("echo", handler), group=-1)
 
+        # Register the toggle command
+        app.add_handler(TelegramCommandHandler('toggle_status', self.toggle_status_message, filters=filters.User(user_id=self.admin_users)))
+
         self.logger.info("Bot started successfully!")
         
         self.app = app
+
+        # Add job to send status message every 30 minutes
+        self.send_status_interval = 1 * 60
+        job_queue: JobQueue = self.app.job_queue
+        job_queue.run_repeating(self.send_status_message, interval=self.send_status_interval, first=0)    
+        self.job_queue = job_queue    
         
         # Call post_init after initializing the bot
         app.run_polling()
\ No newline at end of file
